#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// RSI con Bandas de Bollinger
    /// </summary>
    [Description("RSI con Bandas de Bollinger")]
    public class ZiRSIBollinger : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int perioRSI = 48; // Default setting for PerioRSI
            private int perioBB = 89; // Default setting for PerioBB
            private int desviacion = 2; // Default setting for Desviacion
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Orange), PlotStyle.Line, "Plot0"));
            Add(new Plot(Color.FromKnownColor(KnownColor.LightSteelBlue), PlotStyle.Line, "Plot1"));
            Add(new Plot(Color.FromKnownColor(KnownColor.LightSteelBlue), PlotStyle.Line, "Plot2"));
            Add(new Plot(Color.FromKnownColor(KnownColor.LightSteelBlue), PlotStyle.Line, "Plot3"));
			
			Add(new Line(Color.Gray, 70, "Upper"));
			Add(new Line(Color.Gray, 30, "Lower"));
			Add(new Line(Color.Red, 50, "Banda50"));
			
            CalculateOnBarClose	= false;
            Overlay				= false;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
            // Use this method for calculating your indicator values. Assign a value to each
            // plot below by replacing 'Close[0]' with your own formula.
            Plot0.Set(RSI(perioRSI,1)[0]) ;
			
			DrawOnPricePanel = false;
			DrawRegion("Bollinger Region", CurrentBar, 0, Bollinger(RSI(perioRSI,1),desviacion, perioBB).Upper, Bollinger(RSI(perioRSI,1),desviacion, perioBB).Lower, Color.Black, Color.Blue, 2);
			
			
            //Plot1.Set(Bollinger(RSI(perioRSI,1),desviacion,perioBB).Upper[0]);
            //Plot2.Set(Bollinger(RSI(perioRSI,1),desviacion,perioBB).Lower[0]);
            Plot3.Set(SMA(RSI(perioRSI,1),perioBB)[0]) ;
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot0
        {
            get { return Values[0]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot1
        {
            get { return Values[1]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot2
        {
            get { return Values[2]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot3
        {
            get { return Values[3]; }
        }

        [Description("Período RSI")]
        [Category("Parameters")]
        public int PerioRSI
        {
            get { return perioRSI; }
            set { perioRSI = Math.Max(1, value); }
        }

        [Description("Período Bandas de Bollinger")]
        [Category("Parameters")]
        public int PerioBB
        {
            get { return perioBB; }
            set { perioBB = Math.Max(1, value); }
        }

        [Description("Desviación")]
        [Category("Parameters")]
        public int Desviacion
        {
            get { return desviacion; }
            set { desviacion = Math.Max(1, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private ZiRSIBollinger[] cacheZiRSIBollinger = null;

        private static ZiRSIBollinger checkZiRSIBollinger = new ZiRSIBollinger();

        /// <summary>
        /// RSI con Bandas de Bollinger
        /// </summary>
        /// <returns></returns>
        public ZiRSIBollinger ZiRSIBollinger(int desviacion, int perioBB, int perioRSI)
        {
            return ZiRSIBollinger(Input, desviacion, perioBB, perioRSI);
        }

        /// <summary>
        /// RSI con Bandas de Bollinger
        /// </summary>
        /// <returns></returns>
        public ZiRSIBollinger ZiRSIBollinger(Data.IDataSeries input, int desviacion, int perioBB, int perioRSI)
        {
            checkZiRSIBollinger.Desviacion = desviacion;
            desviacion = checkZiRSIBollinger.Desviacion;
            checkZiRSIBollinger.PerioBB = perioBB;
            perioBB = checkZiRSIBollinger.PerioBB;
            checkZiRSIBollinger.PerioRSI = perioRSI;
            perioRSI = checkZiRSIBollinger.PerioRSI;

            if (cacheZiRSIBollinger != null)
                for (int idx = 0; idx < cacheZiRSIBollinger.Length; idx++)
                    if (cacheZiRSIBollinger[idx].Desviacion == desviacion && cacheZiRSIBollinger[idx].PerioBB == perioBB && cacheZiRSIBollinger[idx].PerioRSI == perioRSI && cacheZiRSIBollinger[idx].EqualsInput(input))
                        return cacheZiRSIBollinger[idx];

            ZiRSIBollinger indicator = new ZiRSIBollinger();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.Desviacion = desviacion;
            indicator.PerioBB = perioBB;
            indicator.PerioRSI = perioRSI;
            indicator.SetUp();

            ZiRSIBollinger[] tmp = new ZiRSIBollinger[cacheZiRSIBollinger == null ? 1 : cacheZiRSIBollinger.Length + 1];
            if (cacheZiRSIBollinger != null)
                cacheZiRSIBollinger.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheZiRSIBollinger = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// RSI con Bandas de Bollinger
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.ZiRSIBollinger ZiRSIBollinger(int desviacion, int perioBB, int perioRSI)
        {
            return _indicator.ZiRSIBollinger(Input, desviacion, perioBB, perioRSI);
        }

        /// <summary>
        /// RSI con Bandas de Bollinger
        /// </summary>
        /// <returns></returns>
        public Indicator.ZiRSIBollinger ZiRSIBollinger(Data.IDataSeries input, int desviacion, int perioBB, int perioRSI)
        {
            return _indicator.ZiRSIBollinger(input, desviacion, perioBB, perioRSI);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// RSI con Bandas de Bollinger
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.ZiRSIBollinger ZiRSIBollinger(int desviacion, int perioBB, int perioRSI)
        {
            return _indicator.ZiRSIBollinger(Input, desviacion, perioBB, perioRSI);
        }

        /// <summary>
        /// RSI con Bandas de Bollinger
        /// </summary>
        /// <returns></returns>
        public Indicator.ZiRSIBollinger ZiRSIBollinger(Data.IDataSeries input, int desviacion, int perioBB, int perioRSI)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.ZiRSIBollinger(input, desviacion, perioBB, perioRSI);
        }

    }
}
#endregion
